# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class ScreenShareConversationNotificationScreenShareMediaParticipant(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ScreenShareConversationNotificationScreenShareMediaParticipant - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'address': 'str',
            'start_time': 'datetime',
            'connected_time': 'datetime',
            'end_time': 'datetime',
            'start_hold_time': 'datetime',
            'purpose': 'str',
            'state': 'str',
            'direction': 'str',
            'disconnect_type': 'str',
            'held': 'bool',
            'wrapup_required': 'bool',
            'wrapup_prompt': 'str',
            'user': 'DocumentDataNotificationCreatedBy',
            'queue': 'ScreenShareConversationNotificationUriReference',
            'attributes': 'dict(str, str)',
            'error_info': 'ScreenShareConversationNotificationErrorInfo',
            'script': 'ScreenShareConversationNotificationUriReference',
            'wrapup_timeout_ms': 'int',
            'wrapup_skipped': 'bool',
            'provider': 'str',
            'external_contact': 'ScreenShareConversationNotificationUriReference',
            'external_organization': 'ScreenShareConversationNotificationUriReference',
            'context': 'str',
            'peer_count': 'int',
            'sharing': 'bool'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'address': 'address',
            'start_time': 'startTime',
            'connected_time': 'connectedTime',
            'end_time': 'endTime',
            'start_hold_time': 'startHoldTime',
            'purpose': 'purpose',
            'state': 'state',
            'direction': 'direction',
            'disconnect_type': 'disconnectType',
            'held': 'held',
            'wrapup_required': 'wrapupRequired',
            'wrapup_prompt': 'wrapupPrompt',
            'user': 'user',
            'queue': 'queue',
            'attributes': 'attributes',
            'error_info': 'errorInfo',
            'script': 'script',
            'wrapup_timeout_ms': 'wrapupTimeoutMs',
            'wrapup_skipped': 'wrapupSkipped',
            'provider': 'provider',
            'external_contact': 'externalContact',
            'external_organization': 'externalOrganization',
            'context': 'context',
            'peer_count': 'peerCount',
            'sharing': 'sharing'
        }

        self._id = None
        self._name = None
        self._address = None
        self._start_time = None
        self._connected_time = None
        self._end_time = None
        self._start_hold_time = None
        self._purpose = None
        self._state = None
        self._direction = None
        self._disconnect_type = None
        self._held = None
        self._wrapup_required = None
        self._wrapup_prompt = None
        self._user = None
        self._queue = None
        self._attributes = None
        self._error_info = None
        self._script = None
        self._wrapup_timeout_ms = None
        self._wrapup_skipped = None
        self._provider = None
        self._external_contact = None
        self._external_organization = None
        self._context = None
        self._peer_count = None
        self._sharing = None

    @property
    def id(self):
        """
        Gets the id of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :return: The id of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :param id: The id of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :return: The name of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :param name: The name of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :type: str
        """
        
        self._name = name

    @property
    def address(self):
        """
        Gets the address of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :return: The address of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """
        Sets the address of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :param address: The address of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :type: str
        """
        
        self._address = address

    @property
    def start_time(self):
        """
        Gets the start_time of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :return: The start_time of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """
        Sets the start_time of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :param start_time: The start_time of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :type: datetime
        """
        
        self._start_time = start_time

    @property
    def connected_time(self):
        """
        Gets the connected_time of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :return: The connected_time of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :rtype: datetime
        """
        return self._connected_time

    @connected_time.setter
    def connected_time(self, connected_time):
        """
        Sets the connected_time of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :param connected_time: The connected_time of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :type: datetime
        """
        
        self._connected_time = connected_time

    @property
    def end_time(self):
        """
        Gets the end_time of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :return: The end_time of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :rtype: datetime
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """
        Sets the end_time of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :param end_time: The end_time of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :type: datetime
        """
        
        self._end_time = end_time

    @property
    def start_hold_time(self):
        """
        Gets the start_hold_time of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :return: The start_hold_time of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :rtype: datetime
        """
        return self._start_hold_time

    @start_hold_time.setter
    def start_hold_time(self, start_hold_time):
        """
        Sets the start_hold_time of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :param start_hold_time: The start_hold_time of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :type: datetime
        """
        
        self._start_hold_time = start_hold_time

    @property
    def purpose(self):
        """
        Gets the purpose of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :return: The purpose of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :rtype: str
        """
        return self._purpose

    @purpose.setter
    def purpose(self, purpose):
        """
        Sets the purpose of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :param purpose: The purpose of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :type: str
        """
        
        self._purpose = purpose

    @property
    def state(self):
        """
        Gets the state of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :return: The state of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :param state: The state of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :type: str
        """
        allowed_values = ["alerting", "dialing", "contacting", "offering", "connected", "disconnected", "terminated", "converting", "uploading", "transmitting", "scheduled", "none"]
        if state.lower() not in map(str.lower, allowed_values):
            # print "Invalid value for state -> " + state
            self._state = "outdated_sdk_version"
        else:
            self._state = state.lower()

    @property
    def direction(self):
        """
        Gets the direction of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :return: The direction of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :rtype: str
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """
        Sets the direction of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :param direction: The direction of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :type: str
        """
        allowed_values = ["inbound", "outbound"]
        if direction.lower() not in map(str.lower, allowed_values):
            # print "Invalid value for direction -> " + direction
            self._direction = "outdated_sdk_version"
        else:
            self._direction = direction.lower()

    @property
    def disconnect_type(self):
        """
        Gets the disconnect_type of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :return: The disconnect_type of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :rtype: str
        """
        return self._disconnect_type

    @disconnect_type.setter
    def disconnect_type(self, disconnect_type):
        """
        Sets the disconnect_type of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :param disconnect_type: The disconnect_type of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :type: str
        """
        allowed_values = ["endpoint", "client", "system", "transfer", "timeout", "transfer.conference", "transfer.consult", "transfer.forward", "transfer.noanswer", "transfer.notavailable", "transport.failure", "error", "peer", "other", "spam"]
        if disconnect_type.lower() not in map(str.lower, allowed_values):
            # print "Invalid value for disconnect_type -> " + disconnect_type
            self._disconnect_type = "outdated_sdk_version"
        else:
            self._disconnect_type = disconnect_type.lower()

    @property
    def held(self):
        """
        Gets the held of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :return: The held of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :rtype: bool
        """
        return self._held

    @held.setter
    def held(self, held):
        """
        Sets the held of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :param held: The held of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :type: bool
        """
        
        self._held = held

    @property
    def wrapup_required(self):
        """
        Gets the wrapup_required of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :return: The wrapup_required of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :rtype: bool
        """
        return self._wrapup_required

    @wrapup_required.setter
    def wrapup_required(self, wrapup_required):
        """
        Sets the wrapup_required of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :param wrapup_required: The wrapup_required of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :type: bool
        """
        
        self._wrapup_required = wrapup_required

    @property
    def wrapup_prompt(self):
        """
        Gets the wrapup_prompt of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :return: The wrapup_prompt of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :rtype: str
        """
        return self._wrapup_prompt

    @wrapup_prompt.setter
    def wrapup_prompt(self, wrapup_prompt):
        """
        Sets the wrapup_prompt of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :param wrapup_prompt: The wrapup_prompt of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :type: str
        """
        
        self._wrapup_prompt = wrapup_prompt

    @property
    def user(self):
        """
        Gets the user of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :return: The user of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :rtype: DocumentDataNotificationCreatedBy
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :param user: The user of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :type: DocumentDataNotificationCreatedBy
        """
        
        self._user = user

    @property
    def queue(self):
        """
        Gets the queue of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :return: The queue of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :rtype: ScreenShareConversationNotificationUriReference
        """
        return self._queue

    @queue.setter
    def queue(self, queue):
        """
        Sets the queue of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :param queue: The queue of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :type: ScreenShareConversationNotificationUriReference
        """
        
        self._queue = queue

    @property
    def attributes(self):
        """
        Gets the attributes of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :return: The attributes of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :rtype: dict(str, str)
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """
        Sets the attributes of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :param attributes: The attributes of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :type: dict(str, str)
        """
        
        self._attributes = attributes

    @property
    def error_info(self):
        """
        Gets the error_info of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :return: The error_info of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :rtype: ScreenShareConversationNotificationErrorInfo
        """
        return self._error_info

    @error_info.setter
    def error_info(self, error_info):
        """
        Sets the error_info of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :param error_info: The error_info of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :type: ScreenShareConversationNotificationErrorInfo
        """
        
        self._error_info = error_info

    @property
    def script(self):
        """
        Gets the script of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :return: The script of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :rtype: ScreenShareConversationNotificationUriReference
        """
        return self._script

    @script.setter
    def script(self, script):
        """
        Sets the script of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :param script: The script of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :type: ScreenShareConversationNotificationUriReference
        """
        
        self._script = script

    @property
    def wrapup_timeout_ms(self):
        """
        Gets the wrapup_timeout_ms of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :return: The wrapup_timeout_ms of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :rtype: int
        """
        return self._wrapup_timeout_ms

    @wrapup_timeout_ms.setter
    def wrapup_timeout_ms(self, wrapup_timeout_ms):
        """
        Sets the wrapup_timeout_ms of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :param wrapup_timeout_ms: The wrapup_timeout_ms of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :type: int
        """
        
        self._wrapup_timeout_ms = wrapup_timeout_ms

    @property
    def wrapup_skipped(self):
        """
        Gets the wrapup_skipped of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :return: The wrapup_skipped of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :rtype: bool
        """
        return self._wrapup_skipped

    @wrapup_skipped.setter
    def wrapup_skipped(self, wrapup_skipped):
        """
        Sets the wrapup_skipped of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :param wrapup_skipped: The wrapup_skipped of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :type: bool
        """
        
        self._wrapup_skipped = wrapup_skipped

    @property
    def provider(self):
        """
        Gets the provider of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :return: The provider of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """
        Sets the provider of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :param provider: The provider of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :type: str
        """
        
        self._provider = provider

    @property
    def external_contact(self):
        """
        Gets the external_contact of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :return: The external_contact of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :rtype: ScreenShareConversationNotificationUriReference
        """
        return self._external_contact

    @external_contact.setter
    def external_contact(self, external_contact):
        """
        Sets the external_contact of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :param external_contact: The external_contact of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :type: ScreenShareConversationNotificationUriReference
        """
        
        self._external_contact = external_contact

    @property
    def external_organization(self):
        """
        Gets the external_organization of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :return: The external_organization of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :rtype: ScreenShareConversationNotificationUriReference
        """
        return self._external_organization

    @external_organization.setter
    def external_organization(self, external_organization):
        """
        Sets the external_organization of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :param external_organization: The external_organization of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :type: ScreenShareConversationNotificationUriReference
        """
        
        self._external_organization = external_organization

    @property
    def context(self):
        """
        Gets the context of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :return: The context of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :rtype: str
        """
        return self._context

    @context.setter
    def context(self, context):
        """
        Sets the context of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :param context: The context of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :type: str
        """
        
        self._context = context

    @property
    def peer_count(self):
        """
        Gets the peer_count of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :return: The peer_count of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :rtype: int
        """
        return self._peer_count

    @peer_count.setter
    def peer_count(self, peer_count):
        """
        Sets the peer_count of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :param peer_count: The peer_count of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :type: int
        """
        
        self._peer_count = peer_count

    @property
    def sharing(self):
        """
        Gets the sharing of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :return: The sharing of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :rtype: bool
        """
        return self._sharing

    @sharing.setter
    def sharing(self, sharing):
        """
        Sets the sharing of this ScreenShareConversationNotificationScreenShareMediaParticipant.


        :param sharing: The sharing of this ScreenShareConversationNotificationScreenShareMediaParticipant.
        :type: bool
        """
        
        self._sharing = sharing

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class CampaignNotification(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        CampaignNotification - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'version': 'int',
            'additional_properties': 'object',
            'contact_list': 'DocumentDataNotificationCreatedBy',
            'queue': 'CampaignNotificationUriReference',
            'dialing_mode': 'str',
            'script': 'CampaignNotificationUriReference',
            'edge_group': 'CampaignNotificationUriReference',
            'campaign_status': 'str',
            'phone_columns': 'list[CampaignNotificationPhoneColumns]',
            'abandon_rate': 'float',
            'dnc_lists': 'list[CampaignNotificationUriReference]',
            'callable_time_set': 'CampaignNotificationUriReference',
            'call_analysis_response_set': 'CampaignNotificationUriReference',
            'caller_name': 'str',
            'caller_address': 'str',
            'outbound_line_count': 'int',
            'errors': 'list[CampaignNotificationErrors]',
            'rule_sets': 'list[CampaignNotificationUriReference]',
            'skip_preview_disabled': 'bool',
            'preview_time_out_seconds': 'int',
            'single_number_preview': 'bool',
            'contact_sort': 'CampaignNotificationContactSort',
            'no_answer_timeout': 'int',
            'call_analysis_language': 'str',
            'priority': 'int'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'version': 'version',
            'additional_properties': 'additionalProperties',
            'contact_list': 'contactList',
            'queue': 'queue',
            'dialing_mode': 'dialingMode',
            'script': 'script',
            'edge_group': 'edgeGroup',
            'campaign_status': 'campaignStatus',
            'phone_columns': 'phoneColumns',
            'abandon_rate': 'abandonRate',
            'dnc_lists': 'dncLists',
            'callable_time_set': 'callableTimeSet',
            'call_analysis_response_set': 'callAnalysisResponseSet',
            'caller_name': 'callerName',
            'caller_address': 'callerAddress',
            'outbound_line_count': 'outboundLineCount',
            'errors': 'errors',
            'rule_sets': 'ruleSets',
            'skip_preview_disabled': 'skipPreviewDisabled',
            'preview_time_out_seconds': 'previewTimeOutSeconds',
            'single_number_preview': 'singleNumberPreview',
            'contact_sort': 'contactSort',
            'no_answer_timeout': 'noAnswerTimeout',
            'call_analysis_language': 'callAnalysisLanguage',
            'priority': 'priority'
        }

        self._id = None
        self._name = None
        self._date_created = None
        self._date_modified = None
        self._version = None
        self._additional_properties = None
        self._contact_list = None
        self._queue = None
        self._dialing_mode = None
        self._script = None
        self._edge_group = None
        self._campaign_status = None
        self._phone_columns = None
        self._abandon_rate = None
        self._dnc_lists = None
        self._callable_time_set = None
        self._call_analysis_response_set = None
        self._caller_name = None
        self._caller_address = None
        self._outbound_line_count = None
        self._errors = None
        self._rule_sets = None
        self._skip_preview_disabled = None
        self._preview_time_out_seconds = None
        self._single_number_preview = None
        self._contact_sort = None
        self._no_answer_timeout = None
        self._call_analysis_language = None
        self._priority = None

    @property
    def id(self):
        """
        Gets the id of this CampaignNotification.


        :return: The id of this CampaignNotification.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this CampaignNotification.


        :param id: The id of this CampaignNotification.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this CampaignNotification.


        :return: The name of this CampaignNotification.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CampaignNotification.


        :param name: The name of this CampaignNotification.
        :type: str
        """
        
        self._name = name

    @property
    def date_created(self):
        """
        Gets the date_created of this CampaignNotification.


        :return: The date_created of this CampaignNotification.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this CampaignNotification.


        :param date_created: The date_created of this CampaignNotification.
        :type: datetime
        """
        
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this CampaignNotification.


        :return: The date_modified of this CampaignNotification.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this CampaignNotification.


        :param date_modified: The date_modified of this CampaignNotification.
        :type: datetime
        """
        
        self._date_modified = date_modified

    @property
    def version(self):
        """
        Gets the version of this CampaignNotification.


        :return: The version of this CampaignNotification.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this CampaignNotification.


        :param version: The version of this CampaignNotification.
        :type: int
        """
        
        self._version = version

    @property
    def additional_properties(self):
        """
        Gets the additional_properties of this CampaignNotification.


        :return: The additional_properties of this CampaignNotification.
        :rtype: object
        """
        return self._additional_properties

    @additional_properties.setter
    def additional_properties(self, additional_properties):
        """
        Sets the additional_properties of this CampaignNotification.


        :param additional_properties: The additional_properties of this CampaignNotification.
        :type: object
        """
        
        self._additional_properties = additional_properties

    @property
    def contact_list(self):
        """
        Gets the contact_list of this CampaignNotification.


        :return: The contact_list of this CampaignNotification.
        :rtype: DocumentDataNotificationCreatedBy
        """
        return self._contact_list

    @contact_list.setter
    def contact_list(self, contact_list):
        """
        Sets the contact_list of this CampaignNotification.


        :param contact_list: The contact_list of this CampaignNotification.
        :type: DocumentDataNotificationCreatedBy
        """
        
        self._contact_list = contact_list

    @property
    def queue(self):
        """
        Gets the queue of this CampaignNotification.


        :return: The queue of this CampaignNotification.
        :rtype: CampaignNotificationUriReference
        """
        return self._queue

    @queue.setter
    def queue(self, queue):
        """
        Sets the queue of this CampaignNotification.


        :param queue: The queue of this CampaignNotification.
        :type: CampaignNotificationUriReference
        """
        
        self._queue = queue

    @property
    def dialing_mode(self):
        """
        Gets the dialing_mode of this CampaignNotification.


        :return: The dialing_mode of this CampaignNotification.
        :rtype: str
        """
        return self._dialing_mode

    @dialing_mode.setter
    def dialing_mode(self, dialing_mode):
        """
        Sets the dialing_mode of this CampaignNotification.


        :param dialing_mode: The dialing_mode of this CampaignNotification.
        :type: str
        """
        allowed_values = ["AGENTLESS", "PREVIEW", "POWER", "PREDICTIVE", "PROGRESSIVE"]
        if dialing_mode.lower() not in map(str.lower, allowed_values):
            # print "Invalid value for dialing_mode -> " + dialing_mode
            self._dialing_mode = "outdated_sdk_version"
        else:
            self._dialing_mode = dialing_mode.lower()

    @property
    def script(self):
        """
        Gets the script of this CampaignNotification.


        :return: The script of this CampaignNotification.
        :rtype: CampaignNotificationUriReference
        """
        return self._script

    @script.setter
    def script(self, script):
        """
        Sets the script of this CampaignNotification.


        :param script: The script of this CampaignNotification.
        :type: CampaignNotificationUriReference
        """
        
        self._script = script

    @property
    def edge_group(self):
        """
        Gets the edge_group of this CampaignNotification.


        :return: The edge_group of this CampaignNotification.
        :rtype: CampaignNotificationUriReference
        """
        return self._edge_group

    @edge_group.setter
    def edge_group(self, edge_group):
        """
        Sets the edge_group of this CampaignNotification.


        :param edge_group: The edge_group of this CampaignNotification.
        :type: CampaignNotificationUriReference
        """
        
        self._edge_group = edge_group

    @property
    def campaign_status(self):
        """
        Gets the campaign_status of this CampaignNotification.


        :return: The campaign_status of this CampaignNotification.
        :rtype: str
        """
        return self._campaign_status

    @campaign_status.setter
    def campaign_status(self, campaign_status):
        """
        Sets the campaign_status of this CampaignNotification.


        :param campaign_status: The campaign_status of this CampaignNotification.
        :type: str
        """
        allowed_values = ["ON", "OFF", "COMPLETE", "STOPPING", "INVALID"]
        if campaign_status.lower() not in map(str.lower, allowed_values):
            # print "Invalid value for campaign_status -> " + campaign_status
            self._campaign_status = "outdated_sdk_version"
        else:
            self._campaign_status = campaign_status.lower()

    @property
    def phone_columns(self):
        """
        Gets the phone_columns of this CampaignNotification.


        :return: The phone_columns of this CampaignNotification.
        :rtype: list[CampaignNotificationPhoneColumns]
        """
        return self._phone_columns

    @phone_columns.setter
    def phone_columns(self, phone_columns):
        """
        Sets the phone_columns of this CampaignNotification.


        :param phone_columns: The phone_columns of this CampaignNotification.
        :type: list[CampaignNotificationPhoneColumns]
        """
        
        self._phone_columns = phone_columns

    @property
    def abandon_rate(self):
        """
        Gets the abandon_rate of this CampaignNotification.


        :return: The abandon_rate of this CampaignNotification.
        :rtype: float
        """
        return self._abandon_rate

    @abandon_rate.setter
    def abandon_rate(self, abandon_rate):
        """
        Sets the abandon_rate of this CampaignNotification.


        :param abandon_rate: The abandon_rate of this CampaignNotification.
        :type: float
        """
        
        self._abandon_rate = abandon_rate

    @property
    def dnc_lists(self):
        """
        Gets the dnc_lists of this CampaignNotification.


        :return: The dnc_lists of this CampaignNotification.
        :rtype: list[CampaignNotificationUriReference]
        """
        return self._dnc_lists

    @dnc_lists.setter
    def dnc_lists(self, dnc_lists):
        """
        Sets the dnc_lists of this CampaignNotification.


        :param dnc_lists: The dnc_lists of this CampaignNotification.
        :type: list[CampaignNotificationUriReference]
        """
        
        self._dnc_lists = dnc_lists

    @property
    def callable_time_set(self):
        """
        Gets the callable_time_set of this CampaignNotification.


        :return: The callable_time_set of this CampaignNotification.
        :rtype: CampaignNotificationUriReference
        """
        return self._callable_time_set

    @callable_time_set.setter
    def callable_time_set(self, callable_time_set):
        """
        Sets the callable_time_set of this CampaignNotification.


        :param callable_time_set: The callable_time_set of this CampaignNotification.
        :type: CampaignNotificationUriReference
        """
        
        self._callable_time_set = callable_time_set

    @property
    def call_analysis_response_set(self):
        """
        Gets the call_analysis_response_set of this CampaignNotification.


        :return: The call_analysis_response_set of this CampaignNotification.
        :rtype: CampaignNotificationUriReference
        """
        return self._call_analysis_response_set

    @call_analysis_response_set.setter
    def call_analysis_response_set(self, call_analysis_response_set):
        """
        Sets the call_analysis_response_set of this CampaignNotification.


        :param call_analysis_response_set: The call_analysis_response_set of this CampaignNotification.
        :type: CampaignNotificationUriReference
        """
        
        self._call_analysis_response_set = call_analysis_response_set

    @property
    def caller_name(self):
        """
        Gets the caller_name of this CampaignNotification.


        :return: The caller_name of this CampaignNotification.
        :rtype: str
        """
        return self._caller_name

    @caller_name.setter
    def caller_name(self, caller_name):
        """
        Sets the caller_name of this CampaignNotification.


        :param caller_name: The caller_name of this CampaignNotification.
        :type: str
        """
        
        self._caller_name = caller_name

    @property
    def caller_address(self):
        """
        Gets the caller_address of this CampaignNotification.


        :return: The caller_address of this CampaignNotification.
        :rtype: str
        """
        return self._caller_address

    @caller_address.setter
    def caller_address(self, caller_address):
        """
        Sets the caller_address of this CampaignNotification.


        :param caller_address: The caller_address of this CampaignNotification.
        :type: str
        """
        
        self._caller_address = caller_address

    @property
    def outbound_line_count(self):
        """
        Gets the outbound_line_count of this CampaignNotification.


        :return: The outbound_line_count of this CampaignNotification.
        :rtype: int
        """
        return self._outbound_line_count

    @outbound_line_count.setter
    def outbound_line_count(self, outbound_line_count):
        """
        Sets the outbound_line_count of this CampaignNotification.


        :param outbound_line_count: The outbound_line_count of this CampaignNotification.
        :type: int
        """
        
        self._outbound_line_count = outbound_line_count

    @property
    def errors(self):
        """
        Gets the errors of this CampaignNotification.


        :return: The errors of this CampaignNotification.
        :rtype: list[CampaignNotificationErrors]
        """
        return self._errors

    @errors.setter
    def errors(self, errors):
        """
        Sets the errors of this CampaignNotification.


        :param errors: The errors of this CampaignNotification.
        :type: list[CampaignNotificationErrors]
        """
        
        self._errors = errors

    @property
    def rule_sets(self):
        """
        Gets the rule_sets of this CampaignNotification.


        :return: The rule_sets of this CampaignNotification.
        :rtype: list[CampaignNotificationUriReference]
        """
        return self._rule_sets

    @rule_sets.setter
    def rule_sets(self, rule_sets):
        """
        Sets the rule_sets of this CampaignNotification.


        :param rule_sets: The rule_sets of this CampaignNotification.
        :type: list[CampaignNotificationUriReference]
        """
        
        self._rule_sets = rule_sets

    @property
    def skip_preview_disabled(self):
        """
        Gets the skip_preview_disabled of this CampaignNotification.


        :return: The skip_preview_disabled of this CampaignNotification.
        :rtype: bool
        """
        return self._skip_preview_disabled

    @skip_preview_disabled.setter
    def skip_preview_disabled(self, skip_preview_disabled):
        """
        Sets the skip_preview_disabled of this CampaignNotification.


        :param skip_preview_disabled: The skip_preview_disabled of this CampaignNotification.
        :type: bool
        """
        
        self._skip_preview_disabled = skip_preview_disabled

    @property
    def preview_time_out_seconds(self):
        """
        Gets the preview_time_out_seconds of this CampaignNotification.


        :return: The preview_time_out_seconds of this CampaignNotification.
        :rtype: int
        """
        return self._preview_time_out_seconds

    @preview_time_out_seconds.setter
    def preview_time_out_seconds(self, preview_time_out_seconds):
        """
        Sets the preview_time_out_seconds of this CampaignNotification.


        :param preview_time_out_seconds: The preview_time_out_seconds of this CampaignNotification.
        :type: int
        """
        
        self._preview_time_out_seconds = preview_time_out_seconds

    @property
    def single_number_preview(self):
        """
        Gets the single_number_preview of this CampaignNotification.


        :return: The single_number_preview of this CampaignNotification.
        :rtype: bool
        """
        return self._single_number_preview

    @single_number_preview.setter
    def single_number_preview(self, single_number_preview):
        """
        Sets the single_number_preview of this CampaignNotification.


        :param single_number_preview: The single_number_preview of this CampaignNotification.
        :type: bool
        """
        
        self._single_number_preview = single_number_preview

    @property
    def contact_sort(self):
        """
        Gets the contact_sort of this CampaignNotification.


        :return: The contact_sort of this CampaignNotification.
        :rtype: CampaignNotificationContactSort
        """
        return self._contact_sort

    @contact_sort.setter
    def contact_sort(self, contact_sort):
        """
        Sets the contact_sort of this CampaignNotification.


        :param contact_sort: The contact_sort of this CampaignNotification.
        :type: CampaignNotificationContactSort
        """
        
        self._contact_sort = contact_sort

    @property
    def no_answer_timeout(self):
        """
        Gets the no_answer_timeout of this CampaignNotification.


        :return: The no_answer_timeout of this CampaignNotification.
        :rtype: int
        """
        return self._no_answer_timeout

    @no_answer_timeout.setter
    def no_answer_timeout(self, no_answer_timeout):
        """
        Sets the no_answer_timeout of this CampaignNotification.


        :param no_answer_timeout: The no_answer_timeout of this CampaignNotification.
        :type: int
        """
        
        self._no_answer_timeout = no_answer_timeout

    @property
    def call_analysis_language(self):
        """
        Gets the call_analysis_language of this CampaignNotification.


        :return: The call_analysis_language of this CampaignNotification.
        :rtype: str
        """
        return self._call_analysis_language

    @call_analysis_language.setter
    def call_analysis_language(self, call_analysis_language):
        """
        Sets the call_analysis_language of this CampaignNotification.


        :param call_analysis_language: The call_analysis_language of this CampaignNotification.
        :type: str
        """
        
        self._call_analysis_language = call_analysis_language

    @property
    def priority(self):
        """
        Gets the priority of this CampaignNotification.


        :return: The priority of this CampaignNotification.
        :rtype: int
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        """
        Sets the priority of this CampaignNotification.


        :param priority: The priority of this CampaignNotification.
        :type: int
        """
        
        self._priority = priority

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class PhonesReboot(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        PhonesReboot - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'phone_ids': 'list[str]',
            'site_id': 'str'
        }

        self.attribute_map = {
            'phone_ids': 'phoneIds',
            'site_id': 'siteId'
        }

        self._phone_ids = None
        self._site_id = None

    @property
    def phone_ids(self):
        """
        Gets the phone_ids of this PhonesReboot.
        The list of phone Ids to reboot.

        :return: The phone_ids of this PhonesReboot.
        :rtype: list[str]
        """
        return self._phone_ids

    @phone_ids.setter
    def phone_ids(self, phone_ids):
        """
        Sets the phone_ids of this PhonesReboot.
        The list of phone Ids to reboot.

        :param phone_ids: The phone_ids of this PhonesReboot.
        :type: list[str]
        """
        
        self._phone_ids = phone_ids

    @property
    def site_id(self):
        """
        Gets the site_id of this PhonesReboot.
        ID of the site for which to reboot all phones at that site. no.active.edge and phone.cannot.resolve errors are ignored.

        :return: The site_id of this PhonesReboot.
        :rtype: str
        """
        return self._site_id

    @site_id.setter
    def site_id(self, site_id):
        """
        Sets the site_id of this PhonesReboot.
        ID of the site for which to reboot all phones at that site. no.active.edge and phone.cannot.resolve errors are ignored.

        :param site_id: The site_id of this PhonesReboot.
        :type: str
        """
        
        self._site_id = site_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class Share(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Share - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'shared_entity_type': 'str',
            'shared_entity': 'UriReference',
            'member_type': 'str',
            'member': 'UriReference',
            'shared_by': 'UriReference',
            'workspace': 'UriReference',
            'user': 'User',
            'group': 'Group',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'shared_entity_type': 'sharedEntityType',
            'shared_entity': 'sharedEntity',
            'member_type': 'memberType',
            'member': 'member',
            'shared_by': 'sharedBy',
            'workspace': 'workspace',
            'user': 'user',
            'group': 'group',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._shared_entity_type = None
        self._shared_entity = None
        self._member_type = None
        self._member = None
        self._shared_by = None
        self._workspace = None
        self._user = None
        self._group = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this Share.
        The globally unique identifier for the object.

        :return: The id of this Share.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Share.
        The globally unique identifier for the object.

        :param id: The id of this Share.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this Share.


        :return: The name of this Share.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Share.


        :param name: The name of this Share.
        :type: str
        """
        
        self._name = name

    @property
    def shared_entity_type(self):
        """
        Gets the shared_entity_type of this Share.


        :return: The shared_entity_type of this Share.
        :rtype: str
        """
        return self._shared_entity_type

    @shared_entity_type.setter
    def shared_entity_type(self, shared_entity_type):
        """
        Sets the shared_entity_type of this Share.


        :param shared_entity_type: The shared_entity_type of this Share.
        :type: str
        """
        allowed_values = ["DOCUMENT"]
        if shared_entity_type.lower() not in map(str.lower, allowed_values):
            # print "Invalid value for shared_entity_type -> " + shared_entity_type
            self._shared_entity_type = "outdated_sdk_version"
        else:
            self._shared_entity_type = shared_entity_type.lower()

    @property
    def shared_entity(self):
        """
        Gets the shared_entity of this Share.


        :return: The shared_entity of this Share.
        :rtype: UriReference
        """
        return self._shared_entity

    @shared_entity.setter
    def shared_entity(self, shared_entity):
        """
        Sets the shared_entity of this Share.


        :param shared_entity: The shared_entity of this Share.
        :type: UriReference
        """
        
        self._shared_entity = shared_entity

    @property
    def member_type(self):
        """
        Gets the member_type of this Share.


        :return: The member_type of this Share.
        :rtype: str
        """
        return self._member_type

    @member_type.setter
    def member_type(self, member_type):
        """
        Sets the member_type of this Share.


        :param member_type: The member_type of this Share.
        :type: str
        """
        allowed_values = ["USER", "GROUP", "PUBLIC"]
        if member_type.lower() not in map(str.lower, allowed_values):
            # print "Invalid value for member_type -> " + member_type
            self._member_type = "outdated_sdk_version"
        else:
            self._member_type = member_type.lower()

    @property
    def member(self):
        """
        Gets the member of this Share.


        :return: The member of this Share.
        :rtype: UriReference
        """
        return self._member

    @member.setter
    def member(self, member):
        """
        Sets the member of this Share.


        :param member: The member of this Share.
        :type: UriReference
        """
        
        self._member = member

    @property
    def shared_by(self):
        """
        Gets the shared_by of this Share.


        :return: The shared_by of this Share.
        :rtype: UriReference
        """
        return self._shared_by

    @shared_by.setter
    def shared_by(self, shared_by):
        """
        Sets the shared_by of this Share.


        :param shared_by: The shared_by of this Share.
        :type: UriReference
        """
        
        self._shared_by = shared_by

    @property
    def workspace(self):
        """
        Gets the workspace of this Share.


        :return: The workspace of this Share.
        :rtype: UriReference
        """
        return self._workspace

    @workspace.setter
    def workspace(self, workspace):
        """
        Sets the workspace of this Share.


        :param workspace: The workspace of this Share.
        :type: UriReference
        """
        
        self._workspace = workspace

    @property
    def user(self):
        """
        Gets the user of this Share.


        :return: The user of this Share.
        :rtype: User
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this Share.


        :param user: The user of this Share.
        :type: User
        """
        
        self._user = user

    @property
    def group(self):
        """
        Gets the group of this Share.


        :return: The group of this Share.
        :rtype: Group
        """
        return self._group

    @group.setter
    def group(self, group):
        """
        Sets the group of this Share.


        :param group: The group of this Share.
        :type: Group
        """
        
        self._group = group

    @property
    def self_uri(self):
        """
        Gets the self_uri of this Share.
        The URI for this object

        :return: The self_uri of this Share.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this Share.
        The URI for this object

        :param self_uri: The self_uri of this Share.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class ConversationNotificationScreenshares(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ConversationNotificationScreenshares - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'state': 'str',
            'pcSelf': 'ConversationNotificationAddress',
            'id': 'str',
            'context': 'str',
            'sharing': 'bool',
            'provider': 'str',
            'disconnect_type': 'str',
            'connected_time': 'datetime',
            'disconnected_time': 'datetime',
            'additional_properties': 'object'
        }

        self.attribute_map = {
            'state': 'state',
            'pcSelf': 'self',
            'id': 'id',
            'context': 'context',
            'sharing': 'sharing',
            'provider': 'provider',
            'disconnect_type': 'disconnectType',
            'connected_time': 'connectedTime',
            'disconnected_time': 'disconnectedTime',
            'additional_properties': 'additionalProperties'
        }

        self._state = None
        self._pcSelf = None
        self._id = None
        self._context = None
        self._sharing = None
        self._provider = None
        self._disconnect_type = None
        self._connected_time = None
        self._disconnected_time = None
        self._additional_properties = None

    @property
    def state(self):
        """
        Gets the state of this ConversationNotificationScreenshares.


        :return: The state of this ConversationNotificationScreenshares.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this ConversationNotificationScreenshares.


        :param state: The state of this ConversationNotificationScreenshares.
        :type: str
        """
        allowed_values = ["ALERTING", "DIALING", "CONTACTING", "OFFERING", "CONNECTED", "DISCONNECTED", "TERMINATED", "NONE"]
        if state.lower() not in map(str.lower, allowed_values):
            # print "Invalid value for state -> " + state
            self._state = "outdated_sdk_version"
        else:
            self._state = state.lower()

    @property
    def pcSelf(self):
        """
        Gets the pcSelf of this ConversationNotificationScreenshares.


        :return: The pcSelf of this ConversationNotificationScreenshares.
        :rtype: ConversationNotificationAddress
        """
        return self._pcSelf

    @pcSelf.setter
    def pcSelf(self, pcSelf):
        """
        Sets the pcSelf of this ConversationNotificationScreenshares.


        :param pcSelf: The pcSelf of this ConversationNotificationScreenshares.
        :type: ConversationNotificationAddress
        """
        
        self._pcSelf = pcSelf

    @property
    def id(self):
        """
        Gets the id of this ConversationNotificationScreenshares.


        :return: The id of this ConversationNotificationScreenshares.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ConversationNotificationScreenshares.


        :param id: The id of this ConversationNotificationScreenshares.
        :type: str
        """
        
        self._id = id

    @property
    def context(self):
        """
        Gets the context of this ConversationNotificationScreenshares.


        :return: The context of this ConversationNotificationScreenshares.
        :rtype: str
        """
        return self._context

    @context.setter
    def context(self, context):
        """
        Sets the context of this ConversationNotificationScreenshares.


        :param context: The context of this ConversationNotificationScreenshares.
        :type: str
        """
        
        self._context = context

    @property
    def sharing(self):
        """
        Gets the sharing of this ConversationNotificationScreenshares.


        :return: The sharing of this ConversationNotificationScreenshares.
        :rtype: bool
        """
        return self._sharing

    @sharing.setter
    def sharing(self, sharing):
        """
        Sets the sharing of this ConversationNotificationScreenshares.


        :param sharing: The sharing of this ConversationNotificationScreenshares.
        :type: bool
        """
        
        self._sharing = sharing

    @property
    def provider(self):
        """
        Gets the provider of this ConversationNotificationScreenshares.


        :return: The provider of this ConversationNotificationScreenshares.
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """
        Sets the provider of this ConversationNotificationScreenshares.


        :param provider: The provider of this ConversationNotificationScreenshares.
        :type: str
        """
        
        self._provider = provider

    @property
    def disconnect_type(self):
        """
        Gets the disconnect_type of this ConversationNotificationScreenshares.


        :return: The disconnect_type of this ConversationNotificationScreenshares.
        :rtype: str
        """
        return self._disconnect_type

    @disconnect_type.setter
    def disconnect_type(self, disconnect_type):
        """
        Sets the disconnect_type of this ConversationNotificationScreenshares.


        :param disconnect_type: The disconnect_type of this ConversationNotificationScreenshares.
        :type: str
        """
        allowed_values = ["ENDPOINT", "CLIENT", "SYSTEM", "TIMEOUT", "TRANSFER", "TRANSFER_CONFERENCE", "TRANSFER_CONSULT", "TRANSFER_FORWARD", "TRANSFER_NOANSWER", "TRANSFER_NOTAVAILABLE", "TRANSPORT_FAILURE", "ERROR", "PEER", "OTHER", "SPAM"]
        if disconnect_type.lower() not in map(str.lower, allowed_values):
            # print "Invalid value for disconnect_type -> " + disconnect_type
            self._disconnect_type = "outdated_sdk_version"
        else:
            self._disconnect_type = disconnect_type.lower()

    @property
    def connected_time(self):
        """
        Gets the connected_time of this ConversationNotificationScreenshares.


        :return: The connected_time of this ConversationNotificationScreenshares.
        :rtype: datetime
        """
        return self._connected_time

    @connected_time.setter
    def connected_time(self, connected_time):
        """
        Sets the connected_time of this ConversationNotificationScreenshares.


        :param connected_time: The connected_time of this ConversationNotificationScreenshares.
        :type: datetime
        """
        
        self._connected_time = connected_time

    @property
    def disconnected_time(self):
        """
        Gets the disconnected_time of this ConversationNotificationScreenshares.


        :return: The disconnected_time of this ConversationNotificationScreenshares.
        :rtype: datetime
        """
        return self._disconnected_time

    @disconnected_time.setter
    def disconnected_time(self, disconnected_time):
        """
        Sets the disconnected_time of this ConversationNotificationScreenshares.


        :param disconnected_time: The disconnected_time of this ConversationNotificationScreenshares.
        :type: datetime
        """
        
        self._disconnected_time = disconnected_time

    @property
    def additional_properties(self):
        """
        Gets the additional_properties of this ConversationNotificationScreenshares.


        :return: The additional_properties of this ConversationNotificationScreenshares.
        :rtype: object
        """
        return self._additional_properties

    @additional_properties.setter
    def additional_properties(self, additional_properties):
        """
        Sets the additional_properties of this ConversationNotificationScreenshares.


        :param additional_properties: The additional_properties of this ConversationNotificationScreenshares.
        :type: object
        """
        
        self._additional_properties = additional_properties

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class CallConversationNotificationFaxStatus(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        CallConversationNotificationFaxStatus - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'direction': 'str',
            'expected_pages': 'int',
            'active_page': 'int',
            'lines_transmitted': 'int',
            'bytes_transmitted': 'int',
            'data_rate': 'int',
            'page_errors': 'int',
            'line_errors': 'int'
        }

        self.attribute_map = {
            'direction': 'direction',
            'expected_pages': 'expectedPages',
            'active_page': 'activePage',
            'lines_transmitted': 'linesTransmitted',
            'bytes_transmitted': 'bytesTransmitted',
            'data_rate': 'dataRate',
            'page_errors': 'pageErrors',
            'line_errors': 'lineErrors'
        }

        self._direction = None
        self._expected_pages = None
        self._active_page = None
        self._lines_transmitted = None
        self._bytes_transmitted = None
        self._data_rate = None
        self._page_errors = None
        self._line_errors = None

    @property
    def direction(self):
        """
        Gets the direction of this CallConversationNotificationFaxStatus.


        :return: The direction of this CallConversationNotificationFaxStatus.
        :rtype: str
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """
        Sets the direction of this CallConversationNotificationFaxStatus.


        :param direction: The direction of this CallConversationNotificationFaxStatus.
        :type: str
        """
        
        self._direction = direction

    @property
    def expected_pages(self):
        """
        Gets the expected_pages of this CallConversationNotificationFaxStatus.


        :return: The expected_pages of this CallConversationNotificationFaxStatus.
        :rtype: int
        """
        return self._expected_pages

    @expected_pages.setter
    def expected_pages(self, expected_pages):
        """
        Sets the expected_pages of this CallConversationNotificationFaxStatus.


        :param expected_pages: The expected_pages of this CallConversationNotificationFaxStatus.
        :type: int
        """
        
        self._expected_pages = expected_pages

    @property
    def active_page(self):
        """
        Gets the active_page of this CallConversationNotificationFaxStatus.


        :return: The active_page of this CallConversationNotificationFaxStatus.
        :rtype: int
        """
        return self._active_page

    @active_page.setter
    def active_page(self, active_page):
        """
        Sets the active_page of this CallConversationNotificationFaxStatus.


        :param active_page: The active_page of this CallConversationNotificationFaxStatus.
        :type: int
        """
        
        self._active_page = active_page

    @property
    def lines_transmitted(self):
        """
        Gets the lines_transmitted of this CallConversationNotificationFaxStatus.


        :return: The lines_transmitted of this CallConversationNotificationFaxStatus.
        :rtype: int
        """
        return self._lines_transmitted

    @lines_transmitted.setter
    def lines_transmitted(self, lines_transmitted):
        """
        Sets the lines_transmitted of this CallConversationNotificationFaxStatus.


        :param lines_transmitted: The lines_transmitted of this CallConversationNotificationFaxStatus.
        :type: int
        """
        
        self._lines_transmitted = lines_transmitted

    @property
    def bytes_transmitted(self):
        """
        Gets the bytes_transmitted of this CallConversationNotificationFaxStatus.


        :return: The bytes_transmitted of this CallConversationNotificationFaxStatus.
        :rtype: int
        """
        return self._bytes_transmitted

    @bytes_transmitted.setter
    def bytes_transmitted(self, bytes_transmitted):
        """
        Sets the bytes_transmitted of this CallConversationNotificationFaxStatus.


        :param bytes_transmitted: The bytes_transmitted of this CallConversationNotificationFaxStatus.
        :type: int
        """
        
        self._bytes_transmitted = bytes_transmitted

    @property
    def data_rate(self):
        """
        Gets the data_rate of this CallConversationNotificationFaxStatus.


        :return: The data_rate of this CallConversationNotificationFaxStatus.
        :rtype: int
        """
        return self._data_rate

    @data_rate.setter
    def data_rate(self, data_rate):
        """
        Sets the data_rate of this CallConversationNotificationFaxStatus.


        :param data_rate: The data_rate of this CallConversationNotificationFaxStatus.
        :type: int
        """
        
        self._data_rate = data_rate

    @property
    def page_errors(self):
        """
        Gets the page_errors of this CallConversationNotificationFaxStatus.


        :return: The page_errors of this CallConversationNotificationFaxStatus.
        :rtype: int
        """
        return self._page_errors

    @page_errors.setter
    def page_errors(self, page_errors):
        """
        Sets the page_errors of this CallConversationNotificationFaxStatus.


        :param page_errors: The page_errors of this CallConversationNotificationFaxStatus.
        :type: int
        """
        
        self._page_errors = page_errors

    @property
    def line_errors(self):
        """
        Gets the line_errors of this CallConversationNotificationFaxStatus.


        :return: The line_errors of this CallConversationNotificationFaxStatus.
        :rtype: int
        """
        return self._line_errors

    @line_errors.setter
    def line_errors(self, line_errors):
        """
        Sets the line_errors of this CallConversationNotificationFaxStatus.


        :param line_errors: The line_errors of this CallConversationNotificationFaxStatus.
        :type: int
        """
        
        self._line_errors = line_errors

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

   ref: https://github.com/swagger-api/swagger-codegen
"""

from __future__ import absolute_import

import os
import sys
import unittest

import swagger_client
from swagger_client.rest import ApiException
from swagger_client.apis.scripts_api import ScriptsApi


class TestScriptsApi(unittest.TestCase):
    """ ScriptsApi unit test stubs """

    def setUp(self):
        self.api = swagger_client.apis.scripts_api.ScriptsApi()

    def tearDown(self):
        pass

    def test_get_published(self):
        """
        Test case for get_published

        Get the published scripts.
        """
        pass

    def test_get_published_script_id(self):
        """
        Test case for get_published_script_id

        Get the published script.
        """
        pass

    def test_get_published_script_id_pages(self):
        """
        Test case for get_published_script_id_pages

        Get the list of published pages
        """
        pass

    def test_get_published_script_id_pages_page_id(self):
        """
        Test case for get_published_script_id_pages_page_id

        Get the published page.
        """
        pass

    def test_get_published_script_id_variables(self):
        """
        Test case for get_published_script_id_variables

        Get the published variables
        """
        pass

    def test_get_script_id(self):
        """
        Test case for get_script_id

        Get a script
        """
        pass

    def test_get_script_id_pages(self):
        """
        Test case for get_script_id_pages

        Get the list of pages
        """
        pass

    def test_get_script_id_pages_page_id(self):
        """
        Test case for get_script_id_pages_page_id

        Get a page
        """
        pass

    def test_get_scripts(self):
        """
        Test case for get_scripts

        Get the list of scripts
        """
        pass


if __name__ == '__main__':
    unittest.main()


# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class AttemptLimitsNotification(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        AttemptLimitsNotification - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'version': 'int',
            'additional_properties': 'object',
            'max_attempts_per_contact': 'int',
            'max_attempts_per_number': 'int',
            'time_zone_id': 'str',
            'reset_period': 'str',
            'recall_entries': 'dict(str, AttemptLimitsNotificationRecallEntries)'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'version': 'version',
            'additional_properties': 'additionalProperties',
            'max_attempts_per_contact': 'maxAttemptsPerContact',
            'max_attempts_per_number': 'maxAttemptsPerNumber',
            'time_zone_id': 'timeZoneId',
            'reset_period': 'resetPeriod',
            'recall_entries': 'recallEntries'
        }

        self._id = None
        self._name = None
        self._date_created = None
        self._date_modified = None
        self._version = None
        self._additional_properties = None
        self._max_attempts_per_contact = None
        self._max_attempts_per_number = None
        self._time_zone_id = None
        self._reset_period = None
        self._recall_entries = None

    @property
    def id(self):
        """
        Gets the id of this AttemptLimitsNotification.


        :return: The id of this AttemptLimitsNotification.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this AttemptLimitsNotification.


        :param id: The id of this AttemptLimitsNotification.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this AttemptLimitsNotification.


        :return: The name of this AttemptLimitsNotification.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this AttemptLimitsNotification.


        :param name: The name of this AttemptLimitsNotification.
        :type: str
        """
        
        self._name = name

    @property
    def date_created(self):
        """
        Gets the date_created of this AttemptLimitsNotification.


        :return: The date_created of this AttemptLimitsNotification.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this AttemptLimitsNotification.


        :param date_created: The date_created of this AttemptLimitsNotification.
        :type: datetime
        """
        
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this AttemptLimitsNotification.


        :return: The date_modified of this AttemptLimitsNotification.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this AttemptLimitsNotification.


        :param date_modified: The date_modified of this AttemptLimitsNotification.
        :type: datetime
        """
        
        self._date_modified = date_modified

    @property
    def version(self):
        """
        Gets the version of this AttemptLimitsNotification.


        :return: The version of this AttemptLimitsNotification.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this AttemptLimitsNotification.


        :param version: The version of this AttemptLimitsNotification.
        :type: int
        """
        
        self._version = version

    @property
    def additional_properties(self):
        """
        Gets the additional_properties of this AttemptLimitsNotification.


        :return: The additional_properties of this AttemptLimitsNotification.
        :rtype: object
        """
        return self._additional_properties

    @additional_properties.setter
    def additional_properties(self, additional_properties):
        """
        Sets the additional_properties of this AttemptLimitsNotification.


        :param additional_properties: The additional_properties of this AttemptLimitsNotification.
        :type: object
        """
        
        self._additional_properties = additional_properties

    @property
    def max_attempts_per_contact(self):
        """
        Gets the max_attempts_per_contact of this AttemptLimitsNotification.


        :return: The max_attempts_per_contact of this AttemptLimitsNotification.
        :rtype: int
        """
        return self._max_attempts_per_contact

    @max_attempts_per_contact.setter
    def max_attempts_per_contact(self, max_attempts_per_contact):
        """
        Sets the max_attempts_per_contact of this AttemptLimitsNotification.


        :param max_attempts_per_contact: The max_attempts_per_contact of this AttemptLimitsNotification.
        :type: int
        """
        
        self._max_attempts_per_contact = max_attempts_per_contact

    @property
    def max_attempts_per_number(self):
        """
        Gets the max_attempts_per_number of this AttemptLimitsNotification.


        :return: The max_attempts_per_number of this AttemptLimitsNotification.
        :rtype: int
        """
        return self._max_attempts_per_number

    @max_attempts_per_number.setter
    def max_attempts_per_number(self, max_attempts_per_number):
        """
        Sets the max_attempts_per_number of this AttemptLimitsNotification.


        :param max_attempts_per_number: The max_attempts_per_number of this AttemptLimitsNotification.
        :type: int
        """
        
        self._max_attempts_per_number = max_attempts_per_number

    @property
    def time_zone_id(self):
        """
        Gets the time_zone_id of this AttemptLimitsNotification.


        :return: The time_zone_id of this AttemptLimitsNotification.
        :rtype: str
        """
        return self._time_zone_id

    @time_zone_id.setter
    def time_zone_id(self, time_zone_id):
        """
        Sets the time_zone_id of this AttemptLimitsNotification.


        :param time_zone_id: The time_zone_id of this AttemptLimitsNotification.
        :type: str
        """
        
        self._time_zone_id = time_zone_id

    @property
    def reset_period(self):
        """
        Gets the reset_period of this AttemptLimitsNotification.


        :return: The reset_period of this AttemptLimitsNotification.
        :rtype: str
        """
        return self._reset_period

    @reset_period.setter
    def reset_period(self, reset_period):
        """
        Sets the reset_period of this AttemptLimitsNotification.


        :param reset_period: The reset_period of this AttemptLimitsNotification.
        :type: str
        """
        allowed_values = ["NEVER", "TODAY"]
        if reset_period.lower() not in map(str.lower, allowed_values):
            # print "Invalid value for reset_period -> " + reset_period
            self._reset_period = "outdated_sdk_version"
        else:
            self._reset_period = reset_period.lower()

    @property
    def recall_entries(self):
        """
        Gets the recall_entries of this AttemptLimitsNotification.


        :return: The recall_entries of this AttemptLimitsNotification.
        :rtype: dict(str, AttemptLimitsNotificationRecallEntries)
        """
        return self._recall_entries

    @recall_entries.setter
    def recall_entries(self, recall_entries):
        """
        Sets the recall_entries of this AttemptLimitsNotification.


        :param recall_entries: The recall_entries of this AttemptLimitsNotification.
        :type: dict(str, AttemptLimitsNotificationRecallEntries)
        """
        
        self._recall_entries = recall_entries

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class LocationDefinition(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        LocationDefinition - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'address': 'LocationAddress',
            'address_verified': 'bool',
            'emergency_number': 'LocationEmergencyNumber',
            'state': 'str',
            'version': 'int',
            'path': 'list[str]',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'address': 'address',
            'address_verified': 'addressVerified',
            'emergency_number': 'emergencyNumber',
            'state': 'state',
            'version': 'version',
            'path': 'path',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._address = None
        self._address_verified = None
        self._emergency_number = None
        self._state = None
        self._version = None
        self._path = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this LocationDefinition.
        The globally unique identifier for the object.

        :return: The id of this LocationDefinition.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this LocationDefinition.
        The globally unique identifier for the object.

        :param id: The id of this LocationDefinition.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this LocationDefinition.


        :return: The name of this LocationDefinition.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this LocationDefinition.


        :param name: The name of this LocationDefinition.
        :type: str
        """
        
        self._name = name

    @property
    def address(self):
        """
        Gets the address of this LocationDefinition.


        :return: The address of this LocationDefinition.
        :rtype: LocationAddress
        """
        return self._address

    @address.setter
    def address(self, address):
        """
        Sets the address of this LocationDefinition.


        :param address: The address of this LocationDefinition.
        :type: LocationAddress
        """
        
        self._address = address

    @property
    def address_verified(self):
        """
        Gets the address_verified of this LocationDefinition.


        :return: The address_verified of this LocationDefinition.
        :rtype: bool
        """
        return self._address_verified

    @address_verified.setter
    def address_verified(self, address_verified):
        """
        Sets the address_verified of this LocationDefinition.


        :param address_verified: The address_verified of this LocationDefinition.
        :type: bool
        """
        
        self._address_verified = address_verified

    @property
    def emergency_number(self):
        """
        Gets the emergency_number of this LocationDefinition.


        :return: The emergency_number of this LocationDefinition.
        :rtype: LocationEmergencyNumber
        """
        return self._emergency_number

    @emergency_number.setter
    def emergency_number(self, emergency_number):
        """
        Sets the emergency_number of this LocationDefinition.


        :param emergency_number: The emergency_number of this LocationDefinition.
        :type: LocationEmergencyNumber
        """
        
        self._emergency_number = emergency_number

    @property
    def state(self):
        """
        Gets the state of this LocationDefinition.
        Current activity status of the location.

        :return: The state of this LocationDefinition.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this LocationDefinition.
        Current activity status of the location.

        :param state: The state of this LocationDefinition.
        :type: str
        """
        allowed_values = ["active", "deleted"]
        if state.lower() not in map(str.lower, allowed_values):
            # print "Invalid value for state -> " + state
            self._state = "outdated_sdk_version"
        else:
            self._state = state.lower()

    @property
    def version(self):
        """
        Gets the version of this LocationDefinition.


        :return: The version of this LocationDefinition.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this LocationDefinition.


        :param version: The version of this LocationDefinition.
        :type: int
        """
        
        self._version = version

    @property
    def path(self):
        """
        Gets the path of this LocationDefinition.


        :return: The path of this LocationDefinition.
        :rtype: list[str]
        """
        return self._path

    @path.setter
    def path(self, path):
        """
        Sets the path of this LocationDefinition.


        :param path: The path of this LocationDefinition.
        :type: list[str]
        """
        
        self._path = path

    @property
    def self_uri(self):
        """
        Gets the self_uri of this LocationDefinition.
        The URI for this object

        :return: The self_uri of this LocationDefinition.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this LocationDefinition.
        The URI for this object

        :param self_uri: The self_uri of this LocationDefinition.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

